# ![Kosmorrolib](https://raw.githubusercontent.com/Kosmorro/logos/main/kosmorrolib/kosmorrolib-artwork.jpg)

[![Coverage Status](https://coveralls.io/repos/github/Kosmorro/lib/badge.svg?branch=main)](https://coveralls.io/github/Kosmorro/lib?branch=main) [![Version on PyPI](https://img.shields.io/pypi/v/kosmorrolib)](https://pypi.org/project/kosmorrolib)  [![IRC: #kosmorro on Libera.Chat](https://img.shields.io/badge/Libera.Chat-%23kosmorro-blueviolet)](https://web.libera.chat/?nick=Astronaut?#kosmorro)

Kosmorrolib is the Python library internally used in Kosmorro. It provides easy-to-use functions for your calculation needs.

The library is built on [Skyfield](https://rhodesmill.org/skyfield/), an excellent library designed to compute positions for any objects in the Solar system.

## Installation

Take a look at [the official documentation](https://kosmorro.space/lib) for the information about how to install this library.

### Development environment

To contribute to Kosmorrolib, you will need [Poetry](https://python-poetry.org), a software to manage the project from development to publishing.

Clone this repository and run `poetry install` to install the dependencies.
And that's all, your development environment is ready!

## Documentation

You can find all the documentation of the library [on the website](https://kosmorro.space/lib/doc).
